@@ -27,8 +27,8 @@ Q_CHARSET_DATABASE_CODE = 0x08
 Q_TABLE_MAP_FOR_UPDATE_CODE = 0x09
 Q_MASTER_DATA_WRITTEN_CODE = 0x0A
 Q_INVOKER = 0x0B
-Q_UPDATED_DB_NAMES = 0x0C
-Q_MICROSECONDS = 0x0D
+Q_UPDATED_DB_NAMES = 0x0C   # MySQL only
+Q_MICROSECONDS = 0x0D       # MySQL only
 Q_COMMIT_TS = 0x0E
 Q_COMMIT_TS2 = 0X0F
 Q_EXPLICIT_DEFAULTS_FOR_TIMESTAMP = 0X10
@@ -36,3 +36,5 @@ Q_DDL_LOGGED_WITH_XID = 0X11
 Q_DEFAULT_COLLATION_FOR_UTF8MB4 = 0X12
 Q_SQL_REQUIRE_PRIMARY_KEY = 0X13
 Q_DEFAULT_TABLE_ENCRYPTION = 0X14
+Q_HRNOW = 0x80  # MariaDB only
+Q_XID = 0x81    # MariaDB only
\ No newline at end of file
