@@ -513,6 +513,16 @@ class TestDataType(base.PyMySQLReplicationTestCase):
 
         self.assertEqual(event.rows[0]["values"]["value"], to_binary_dict(data))
 
+    def test_json_large_array(self):
+        "Test json array larger than 64k bytes"
+        if not self.isMySQL57():
+            self.skipTest("Json is only supported in mysql 5.7")
+        create_query = "CREATE TABLE test (id int, value json);"
+        large_array = dict(my_key=[i for i in range(100000)])
+        insert_query = "INSERT INTO test (id, value) VALUES (1, '%s');" % (json.dumps(large_array),)
+        event = self.create_and_insert_value(create_query, insert_query)
+        self.assertEqual(event.rows[0]["values"]["value"], to_binary_dict(large_array))
+
     def test_json_large_with_literal(self):
         if not self.isMySQL57():
             self.skipTest("Json is only supported in mysql 5.7")
@@ -730,7 +740,7 @@ class TestDataType(base.PyMySQLReplicationTestCase):
             column_type = "INT"
             column_definition.append(column_type)
 
-            nullability = "NOT NULL" if not RowsEvent.__is_null(bit_mask, i) else ""
+            nullability = "NOT NULL" if not RowsEvent._is_null(bit_mask, i) else ""
             column_definition.append(nullability)
 
             columns.append(" ".join(column_definition))
@@ -763,5 +773,31 @@ class TestDataType(base.PyMySQLReplicationTestCase):
         self.assertEqual(event.event_type, TABLE_MAP_EVENT)
         self.assertEqual(event.null_bitmask, bit_mask)
 
+    def test_mariadb_only_status_vars(self):
+        """Test parse of mariadb exclusive status variables (a field in query event)
+
+        A query event for mariadb must be parsed successfully
+        since mariadb exclusive status variables are now taken to account
+        (Q_HRNOW, Q_XID)
+        Test if was parse successful by asserting the last field of the event,
+        'SQL statement'.
+
+        Raises:
+            StatusVariableMismatch: This is the case where new status variables are added to
+            mysql server. Same set of status variables must be added to the library as well.
+        """
+        if not self.isMariaDB():
+            return
+
+        create_query = "CREATE TABLE test (id INTEGER)"
+        event = self.create_table(create_query)
+
+        # skip dummy events with empty schema
+        while event.schema == b'':
+            event = self.stream.fetchone()
+
+        self.assertEqual(event.query, create_query)
+
+
 if __name__ == "__main__":
     unittest.main()
